@@ -2,14 +2,15 @@
 #
 # Code coverage from data only (not unit tests)
 #
-./configure-gcov.sh
+./autogen.sh
+./configure --enable-gcov
 cd src
 make reader
 rm -f libinjection.info
 rm -rf lcov-html
 mkdir lcov-html
-libtool --mode=execute ./reader -q ../data/sqli-*.txt
-libtool --mode=execute ./reader -q -x ../data/xss-*.txt
+../libtool --mode=execute ./reader -q ../data/sqli-*.txt
+../libtool --mode=execute ./reader -q -x ../data/xss-*.txt
 lcov -b . --directory . --capture --output-file libinjection.info
 lcov -b . --directory . --remove libinjection.info '/usr/include*' -o libinjection.info
 lcov -b . --directory . --remove libinjection.info 'reader.c' -o libinjection.info
