@@ -6,5 +6,5 @@ make clean
 make
 cd src
 make reader
-libtool --mode=execute ./reader -s -q ../data/sqli-*.txt ../data/false-*.txt
-libtool --mode=execute gprof ./reader gmon.out
+../libtool --mode=execute ./reader -s -q ../data/sqli-*.txt ../data/false-*.txt
+../libtool --mode=execute gprof ./reader gmon.out
