@@ -13,36 +13,20 @@
  *
  */
 
-#include <string>
-#include <unordered_map>
-
-#include "modsecurity/actions/action.h"
-#include "src/actions/transformations/transformation.h"
-
 #ifndef SRC_ACTIONS_TRANSFORMATIONS_URL_DECODE_H_
 #define SRC_ACTIONS_TRANSFORMATIONS_URL_DECODE_H_
 
-#ifdef __cplusplus
-namespace modsecurity {
-class Transaction;
-
-namespace actions {
-namespace transformations {
+#include "transformation.h"
 
+namespace modsecurity::actions::transformations {
 
 class UrlDecode : public Transformation {
  public:
+    using Transformation::Transformation;
 
-    explicit UrlDecode(const std::string &action) ;
-
-    std::string evaluate(const std::string &exp,
-        Transaction *transaction) override;
+    bool transform(std::string &value, const Transaction *trans) const override;
 };
 
-}  // namespace transformations
-}  // namespace actions
-}  // namespace modsecurity
-
-#endif
+}  // namespace modsecurity::actions::transformations
 
 #endif  // SRC_ACTIONS_TRANSFORMATIONS_URL_DECODE_H_
