@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -33,19 +33,7 @@ class DebugLogWriterAgent : public std::ofstream {
     }
 
     void write(const std::string& msg);
-    bool refCountDecreaseAndCheck() {
-        this->m_referenceCount--;
-        if (this->m_referenceCount == 0) {
-            return true;
-        }
-        return false;
-    }
 
-    void refCountIncrease() {
-        this->m_referenceCount++;
-    }
-
-    int m_referenceCount;
     std::string m_fileName;
 };
 
