@@ -77,7 +77,7 @@ bool InspectFile::evaluate(Transaction *transaction, const std::string &str) {
         pclose(in);
 
         res.append(s.str());
-        if (res.size() > 1 && res.at(0) != '1') {
+        if (res.size() > 1 && res[0] != '1') {
             return true; /* match */
         }
 
