@@ -42,7 +42,7 @@ class Rx : public Operator {
             m_couldContainsMacro = true;
         }
 
-    ~Rx() {
+    ~Rx() override {
         if (m_string->m_containsMacro == false && m_re != NULL) {
             delete m_re;
             m_re = NULL;
@@ -51,7 +51,7 @@ class Rx : public Operator {
 
     bool evaluate(Transaction *transaction, RuleWithActions *rule,
         const std::string& input,
-        std::shared_ptr<RuleMessage> ruleMessage) override;
+        RuleMessage &ruleMessage) override;
 
     bool init(const std::string &arg, std::string *error) override;
 
