@@ -21,25 +21,20 @@ class VerifySVNR : public Operator {
  public:
     /** @ingroup ModSecurity_Operator */
     explicit VerifySVNR(std::unique_ptr<RunTimeString> param)
-        : Operator("VerifySVNR", std::move(param)) {
-        m_re = new Regex(m_param);
-    }
-
-    ~VerifySVNR() {
-        delete m_re;
-    }
+        : Operator("VerifySVNR", std::move(param))
+        , m_re(std::make_unique<Regex>(m_param)) { }
 
     bool operator=(const VerifySVNR &a) = delete;
     VerifySVNR(const VerifySVNR &a) = delete;
 
     bool evaluate(Transaction *transaction, RuleWithActions *rule,
         const std::string& input,
-        std::shared_ptr<RuleMessage> ruleMessage) override;
+        RuleMessage &ruleMessage) override;
 
-    bool verify(const char *ssnumber, int len);
+    bool verify(const char *ssnumber, int len) const;
 
  private:
-    Regex *m_re;
+    std::unique_ptr<Regex> m_re;
     static int convert_to_int(const char c);
     const char bad_svnr[12][11] = { "0000000000",
         "0123456789",
