@@ -30,13 +30,11 @@ void ConfigUnicodeMap::loadConfig(std::string f, double configCodePage,
     RulesSetProperties *driver, std::string *errg) {
     char *buf = NULL;
     char *hmap = NULL;
-    char *p = NULL;
+    const char *p = NULL;
     char *savedptr = NULL;
-    char *ucode = NULL;
-    int code = 0;
+    const char *ucode = NULL;
     int found = 0;
     int length = 0;
-    int Map = 0;
     int processing = 0;
 
     driver->m_unicodeMapTable.m_set = true;
@@ -102,10 +100,10 @@ void ConfigUnicodeMap::loadConfig(std::string f, double configCodePage,
 
             if (mapping != NULL) {
                 ucode = strtok_r(mapping, ":", &hmap);
-                sscanf(ucode, "%x", &code); // cppcheck-suppress invalidScanfArgType_int
-                sscanf(hmap, "%x", &Map);   // cppcheck-suppress invalidScanfArgType_int
+                int code = strtol(ucode, nullptr, 16);
+                int map = strtol(hmap, nullptr, 16);
                 if (code >= 0 && code <= 65535)    {
-                    driver->m_unicodeMapTable.m_unicodeMapTable->change(code, Map);
+                    driver->m_unicodeMapTable.m_unicodeMapTable->change(code, map);
                 }
 
                 free(mapping);
