@@ -1,6 +1,6 @@
 /*
  * ModSecurity, http://www.modsecurity.org/
- * Copyright (c) 2015 Trustwave Holdings, Inc. (http://www.trustwave.com/)
+ * Copyright (c) 2015 - 2021 Trustwave Holdings, Inc. (http://www.trustwave.com/)
  *
  * You may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
@@ -17,7 +17,8 @@
 #include "src/config.h"
 
 #ifdef WIN32
-#include <winsock2.h>
+#include "src/compat/msvc.h"
+#include <WinSock2.h>
 #include <iphlpapi.h>
 #endif
 
@@ -48,7 +49,11 @@
 #endif
 
 #include <stdio.h>
+#ifndef WIN32
 #include <unistd.h>
+#else
+#include <io.h>
+#endif
 #include <string.h>
 
 #include "src/utils/sha1.h"
@@ -72,7 +77,7 @@ void UniqueId::fillUniqueId() {
 
 // Based on:
 // http://stackoverflow.com/questions/16858782/how-to-obtain-almost-unique-system-identifier-in-a-cross-platform-way
-std::string const UniqueId::machineName() {
+std::string UniqueId::machineName() {
     char machine_name[MAX_MACHINE_NAME_SIZE];
     size_t len = MAX_MACHINE_NAME_SIZE;
 #ifdef WIN32
@@ -105,7 +110,7 @@ failed:
 #endif
 }
 
-std::string const UniqueId::ethernetMacAddress() {
+std::string UniqueId::ethernetMacAddress() {
     char mac[MAC_ADDRESS_SIZE];
     memset(mac, '\0', sizeof(char)*(MAC_ADDRESS_SIZE));
 #ifdef DARWIN
@@ -159,7 +164,6 @@ std::string const UniqueId::ethernetMacAddress() {
         }
 
         if (ioctl(sock, SIOCGIFHWADDR, ifr) == 0) {
-            int i = 0;
             if (!ifr->ifr_addr.sa_data[0] && !ifr->ifr_addr.sa_data[1]
                 && !ifr->ifr_addr.sa_data[2]) {
                 continue;
@@ -208,7 +212,7 @@ std::string const UniqueId::ethernetMacAddress() {
     pAdapter = pAdapterInfo;
     while (pAdapter && !mac[0] && !mac[1] && !mac[2]) {
         if (pAdapter->AddressLength > 4) {
-            apr_snprintf(mac, MAC_ADDRESS_SIZE, "%02x:%02x:%02x:%02x:%02x:%02x",
+            snprintf(mac, MAC_ADDRESS_SIZE, "%02x:%02x:%02x:%02x:%02x:%02x",
                 (unsigned char)pAdapter->Address[0],
                 (unsigned char)pAdapter->Address[1],
                 (unsigned char)pAdapter->Address[2],
@@ -223,7 +227,9 @@ std::string const UniqueId::ethernetMacAddress() {
     free(pAdapterInfo);
 #endif
 
+#if defined(__linux__) || defined(__gnu_linux__) || defined(DARWIN) || defined(WIN32)
 end:
+#endif
     return std::string(reinterpret_cast<const char *>(mac));
 #if defined(__linux__) || defined(__gnu_linux__) || defined(DARWIN) || defined(WIN32)
 failed:
