@@ -54,7 +54,7 @@ int main(int argc, char **argv) {
     }
 
 
-    for (auto &x : files) {
+    for (const auto &x : files) {
         std::cout << "Loading file: " << x << std::endl;
         if (modsecRules->loadFromUri(x.c_str()) < 0) {
             std::cout << "Not able to load the rules" << std::endl;
@@ -96,8 +96,8 @@ int main(int argc, char **argv) {
                 }
             }
 
-            if (auto rwo = dynamic_cast<modsecurity::RuleWithOperator *>(z.get())) {
-                std::string op = rwo->getOperatorName();
+            if (const auto *rwo = dynamic_cast<modsecurity::RuleWithOperator *>(z.get())) {
+                const auto &op = rwo->getOperatorName();
                 if (operators.count(op) > 0) {
                     operators[op] = 1 + operators[op];
                 } else {
